@@ -127,6 +127,7 @@ check_kmo <- function(x, ...) {
 #' }
 #'
 #' @importFrom stats pchisq cor
+#' @importFrom insight format_p
 #'
 #' @export
 check_sphericity <- function(x, ...) {
@@ -145,10 +146,10 @@ check_sphericity <- function(x, ...) {
   out <- list(chisq = statistic, p = pval, dof = df)
 
   if (pval < 0.001) {
-    text <- sprintf("Bartlett's test of sphericity suggests that there is sufficient significant correlation in the data for factor analysis (Chisq(%i) = %.2f, %s).", df, statistic, format_p(pval))
+    text <- sprintf("Bartlett's test of sphericity suggests that there is sufficient significant correlation in the data for factor analysis (Chisq(%i) = %.2f, %s).", df, statistic, insight::format_p(pval))
     color <- "green"
   } else {
-    text <- sprintf("Bartlett's test of sphericity suggests that there is not enough significant correlation in the data for factor analysis (Chisq(%i) = %.2f, %s).", df, statistic, format_p(pval))
+    text <- sprintf("Bartlett's test of sphericity suggests that there is not enough significant correlation in the data for factor analysis (Chisq(%i) = %.2f, %s).", df, statistic, insight::format_p(pval))
     color <- "red"
   }
 
