@@ -256,7 +256,7 @@ degrees_of_freedom.betamfx <- degrees_of_freedom.logitor
   if (inherits(dof, "try-error") || is.null(dof)) {
     dof <- Inf
     if (verbose) {
-      insight::print_color("Could not extract degrees of freedom.\n", "red")
+      warning("Could not extract degrees of freedom.", call. = FALSE)
     }
   }
 
