@@ -4,7 +4,18 @@
 #' @importFrom insight get_statistic get_parameters get_sigma
 #' @importFrom stats confint p.adjust.methods p.adjust
 #' @keywords internal
-.extract_parameters_generic <- function(model, ci, component, merge_by = c("Parameter", "Component"), standardize = NULL, effects = "fixed", robust = FALSE, df_method = NULL, p_adjust = NULL, wb_component = FALSE, ...) {
+.extract_parameters_generic <- function(model,
+                                        ci,
+                                        component,
+                                        merge_by = c("Parameter", "Component"),
+                                        standardize = NULL,
+                                        effects = "fixed",
+                                        robust = FALSE,
+                                        df_method = NULL,
+                                        p_adjust = NULL,
+                                        wb_component = FALSE,
+                                        verbose = TRUE,
+                                        ...) {
 
   # ==== check if standardization is required and package available
 
@@ -27,7 +38,7 @@
     standardize <- NULL
   }
 
-  parameters <- insight::get_parameters(model, effects = effects, component = component)
+  parameters <- insight::get_parameters(model, effects = effects, component = component, verbose = verbose)
   statistic <- insight::get_statistic(model, component = component)
 
   # check if all estimates are non-NA
@@ -70,11 +81,26 @@
 
   if (!is.null(ci)) {
     if (isTRUE(robust)) {
-      ci_df <- suppressMessages(ci_robust(model, ci = ci, ...))
+      ci_df <- suppressMessages(ci_robust(model, ci = ci, verbose = verbose, ...))
     } else if (!is.null(df_method)) {
-      ci_df <- suppressMessages(ci(model, ci = ci, effects = effects, component = component, method = df_method))
+      ci_df <- suppressMessages(
+        ci(
+          model,
+          ci = ci,
+          effects = effects,
+          component = component,
+          method = df_method,
+          verbose = verbose
+        )
+      )
     } else {
-      ci_df <- suppressMessages(ci(model, ci = ci, effects = effects, component = component))
+      ci_df <- suppressMessages(ci(
+        model,
+        ci = ci,
+        effects = effects,
+        component = component,
+        verbose = verbose
+      ))
     }
     if (!is.null(ci_df)) {
       if (length(ci) > 1) ci_df <- bayestestR::reshape_ci(ci_df)
@@ -93,9 +119,19 @@
   if (isTRUE(robust)) {
     pval <- p_value_robust(model, ...)
   } else if (!is.null(df_method)) {
-    pval <- p_value(model, effects = effects, component = component, method = df_method)
+    pval <- p_value(
+      model,
+      effects = effects,
+      component = component,
+      method = df_method,
+      verbose = verbose
+    )
   } else {
-    pval <- p_value(model, effects = effects, component = component)
+    pval <- p_value(model,
+      effects = effects,
+      component = component,
+      verbose = verbose
+    )
   }
 
   if (!is.null(pval)) {
@@ -110,9 +146,19 @@
   if (isTRUE(robust)) {
     std_err <- standard_error_robust(model, ...)
   } else if (!is.null(df_method)) {
-    std_err <- standard_error(model, effects = effects, component = component, method = df_method)
+    std_err <- standard_error(
+      model,
+      effects = effects,
+      component = component,
+      method = df_method,
+      verbose = verbose
+    )
   } else {
-    std_err <- standard_error(model, effects = effects, component = component)
+    std_err <- standard_error(model,
+      effects = effects,
+      component = component,
+      verbose = verbose
+    )
   }
 
   if (!is.null(std_err)) {
@@ -219,10 +265,12 @@
 
   # ==== Reorder
 
-  col_order <- c("Parameter", coef_col, "SE", ci_cols, "t", "z", "t / F", "t/F",
-                 "z / Chisq", "z/Chisq", "z / Chi2", "z/Chi2", "F", "Chi2",
-                 "chisq", "chi-squared", "Statistic", "df", "df_error", "p",
-                 "Component", "Response", "Effects")
+  col_order <- c(
+    "Parameter", coef_col, "SE", ci_cols, "t", "z", "t / F", "t/F",
+    "z / Chisq", "z/Chisq", "z / Chi2", "z/Chi2", "F", "Chi2",
+    "chisq", "chi-squared", "Statistic", "df", "df_error", "p",
+    "Component", "Response", "Effects"
+  )
   parameters <- parameters[col_order[col_order %in% names(parameters)]]
 
 
@@ -253,7 +301,14 @@
 
 #' @importFrom stats confint
 #' @keywords internal
-.extract_parameters_mixed <- function(model, ci = .95, df_method = "wald", standardize = NULL, robust = FALSE, p_adjust = NULL, wb_component = FALSE, ...) {
+.extract_parameters_mixed <- function(model,
+                                      ci = .95,
+                                      df_method = "wald",
+                                      standardize = NULL,
+                                      robust = FALSE,
+                                      p_adjust = NULL,
+                                      wb_component = FALSE,
+                                      ...) {
   # check if standardization is required and package available
   if (!is.null(standardize) && !requireNamespace("effectsize", quietly = TRUE)) {
     insight::print_color("Package 'effectsize' required to calculate standardized coefficients. Please install it.\n", "red")
@@ -517,7 +572,19 @@
 #' @importFrom insight is_multivariate
 #' @importFrom stats sd setNames na.omit
 #' @keywords internal
-.extract_parameters_bayesian <- function(model, centrality = "median", dispersion = FALSE, ci = .89, ci_method = "hdi", test = c("pd", "rope"), rope_range = "default", rope_ci = 1.0, bf_prior = NULL, diagnostic = c("ESS", "Rhat"), priors = TRUE, standardize = NULL, ...) {
+.extract_parameters_bayesian <- function(model,
+                                         centrality = "median",
+                                         dispersion = FALSE,
+                                         ci = .89,
+                                         ci_method = "hdi",
+                                         test = c("pd", "rope"),
+                                         rope_range = "default",
+                                         rope_ci = 1.0,
+                                         bf_prior = NULL,
+                                         diagnostic = c("ESS", "Rhat"),
+                                         priors = TRUE,
+                                         standardize = NULL,
+                                         ...) {
   # check if standardization is required and package available
   if (!is.null(standardize) && !requireNamespace("effectsize", quietly = TRUE)) {
     insight::print_color("Package 'effectsize' required to calculate standardized coefficients. Please install it.\n", "red")
@@ -532,19 +599,66 @@
 
   # MCMCglmm need special handling
   if (inherits(model, "MCMCglmm")) {
-    parameters <- bayestestR::describe_posterior(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, diagnostic = "ESS", ...)
+    parameters <- bayestestR::describe_posterior(
+      model,
+      centrality = centrality,
+      dispersion = dispersion,
+      ci = ci,
+      ci_method = ci_method,
+      test = test,
+      rope_range = rope_range,
+      rope_ci = rope_ci,
+      diagnostic = "ESS",
+      ...
+    )
   } else if (!is.null(standardize)) {
-    parameters <- bayestestR::describe_posterior(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, bf_prior = bf_prior, diagnostic = diagnostic, priors = priors, ...)
+    parameters <- bayestestR::describe_posterior(
+      model,
+      centrality = centrality,
+      dispersion = dispersion,
+      ci = ci,
+      ci_method = ci_method,
+      test = test,
+      rope_range = rope_range,
+      rope_ci = rope_ci,
+      bf_prior = bf_prior,
+      diagnostic = diagnostic,
+      priors = priors,
+      ...
+    )
 
     # Don't test BF on standardized params
     test_no_BF <- test[!test %in% c("bf", "bayesfactor", "bayes_factor")]
     if (length(test_no_BF) == 0) test_no_BF <- NULL
     std_post <- effectsize::standardize_posteriors(model, method = standardize)
-    std_parameters <- bayestestR::describe_posterior(std_post, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test_no_BF, rope_range = rope_range, rope_ci = rope_ci, ...)
+    std_parameters <- bayestestR::describe_posterior(
+      std_post,
+      centrality = centrality,
+      dispersion = dispersion,
+      ci = ci,
+      ci_method = ci_method,
+      test = test_no_BF,
+      rope_range = rope_range,
+      rope_ci = rope_ci,
+      ...
+    )
 
     parameters <- merge(std_parameters, parameters[c("Parameter", setdiff(colnames(parameters), colnames(std_parameters)))], sort = FALSE)
   } else {
-    parameters <- bayestestR::describe_posterior(model, centrality = centrality, dispersion = dispersion, ci = ci, ci_method = ci_method, test = test, rope_range = rope_range, rope_ci = rope_ci, bf_prior = bf_prior, diagnostic = diagnostic, priors = priors, ...)
+    parameters <- bayestestR::describe_posterior(
+      model,
+      centrality = centrality,
+      dispersion = dispersion,
+      ci = ci,
+      ci_method = ci_method,
+      test = test,
+      rope_range = rope_range,
+      rope_ci = rope_ci,
+      bf_prior = bf_prior,
+      diagnostic = diagnostic,
+      priors = priors,
+      ...
+    )
   }
 
   if (length(ci) > 1) {
@@ -593,8 +707,35 @@
     warning(paste0("lavaan models only accept one level of CI :( Keeping the first one: `ci = ", ci, "`."))
   }
 
+  # collect dots
+  dot_args <- list(...)
+
+  # list all argument names from the `lavaan` function
+  dot_args <- dot_args[names(dot_args) %in% c(
+    "zstat",
+    "pvalue",
+    "standardized",
+    "fmi",
+    "level",
+    "boot.ci.type",
+    "cov.std",
+    "fmi.options",
+    "rsquare",
+    "remove.system.eq",
+    "remove.eq",
+    "remove.ineq",
+    "remove.def",
+    "remove.nonfree",
+    "add.attributes",
+    "output",
+    "header"
+  )]
+
   # Get estimates
-  data <- lavaan::parameterEstimates(model, se = TRUE, level = ci, ...)
+  data <- do.call(lavaan::parameterEstimates, c(
+    list(object = model, se = TRUE, ci = TRUE, level = ci),
+    dot_args
+  ))
   label <- data$label
 
   # check if standardized estimates are requested, and if so, which type
