@@ -78,7 +78,15 @@ model_parameters.gam <- function(model,
   }
 
   if (exponentiate) parameters <- .exponentiate_parameters(parameters)
-  parameters <- .add_model_parameters_attributes(parameters, model, ci, exponentiate, verbose = verbose, ...)
+  parameters <- .add_model_parameters_attributes(
+    parameters,
+    model,
+    ci,
+    exponentiate,
+    p_adjust = p_adjust,
+    verbose = verbose,
+    ...
+  )
   attr(parameters, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   class(parameters) <- c("parameters_model", "see_parameters_model", class(parameters))
 
