@@ -359,7 +359,11 @@ standard_error.merMod <- function(model, effects = c("fixed", "random"), method
       # Classic and Satterthwaite SE
       if (method %in% c("wald", "satterthwaite")) {
         .data_frame(
-          Parameter = insight::find_parameters(model, effects = "fixed", component = "conditional", flatten = TRUE),
+          Parameter = insight::find_parameters(model,
+            effects = "fixed",
+            component = "conditional",
+            flatten = TRUE
+          ),
           SE = .get_se_from_summary(model)
         )
         # ml1 approx
@@ -379,7 +383,11 @@ standard_error.merMod <- function(model, effects = c("fixed", "random"), method
 
 #' @rdname standard_error
 #' @export
-standard_error.glmmTMB <- function(model, effects = c("fixed", "random"), component = c("all", "conditional", "zi", "zero_inflated", "dispersion"), verbose = TRUE, ...) {
+standard_error.glmmTMB <- function(model,
+                                   effects = c("fixed", "random"),
+                                   component = c("all", "conditional", "zi", "zero_inflated", "dispersion"),
+                                   verbose = TRUE,
+                                   ...) {
   component <- match.arg(component)
   effects <- match.arg(effects)
 
@@ -428,7 +436,11 @@ standard_error.glmmTMB <- function(model, effects = c("fixed", "random"), compon
 #' @rdname standard_error
 #' @importFrom insight find_random
 #' @export
-standard_error.MixMod <- function(model, effects = c("fixed", "random"), component = c("all", "conditional", "zi", "zero_inflated"), verbose = TRUE, ...) {
+standard_error.MixMod <- function(model,
+                                  effects = c("fixed", "random"),
+                                  component = c("all", "conditional", "zi", "zero_inflated"),
+                                  verbose = TRUE,
+                                  ...) {
   component <- match.arg(component)
   effects <- match.arg(effects)
 
@@ -505,7 +517,11 @@ standard_error.HLfit <- function(model, method = NULL, ...) {
 
 #' @rdname standard_error
 #' @export
-standard_error.zeroinfl <- function(model, component = c("all", "conditional", "zi", "zero_inflated"), method = NULL, verbose = TRUE, ...) {
+standard_error.zeroinfl <- function(model,
+                                    component = c("all", "conditional", "zi", "zero_inflated"),
+                                    method = NULL,
+                                    verbose = TRUE,
+                                    ...) {
   component <- match.arg(component)
   if (is.null(.check_component(model, component, verbose = verbose))) {
     return(NULL)
@@ -613,10 +629,6 @@ standard_error.svyglm <- function(model, ...) {
 
 
 
-
-
-
-
 # Survival Models -------------------------------------------------------
 
 
@@ -861,7 +873,10 @@ standard_error.bracl <- function(model, ...) {
 
 
 #' @export
-standard_error.stanreg <- function(model, effects = c("fixed", "random"), component = c("all", "conditional", "zi", "zero_inflated"), ...) {
+standard_error.stanreg <- function(model,
+                                   effects = c("fixed", "random"),
+                                   component = c("all", "conditional", "zi", "zero_inflated"),
+                                   ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
@@ -898,6 +913,12 @@ standard_error.bayesx <- function(model, ...) {
 # Other models ---------------------------------------------------------------
 
 
+#' @export
+standard_error.mediate <- function(model, ...) {
+  NULL
+}
+
+
 #' @export
 standard_error.margins <- function(model, ...) {
   params <- insight::get_parameters(model)
@@ -928,7 +949,7 @@ standard_error.mipo <- function(model, ...) {
 
 
 #' @export
-standard_error.mira <- function(model,...) {
+standard_error.mira <- function(model, ...) {
   if (!requireNamespace("mice", quietly = TRUE)) {
     stop("Package 'mice' needed for this function to work. Please install it.")
   }
@@ -1546,7 +1567,7 @@ standard_error.negbinmfx <- standard_error.poissonmfx
 
 #' @export
 standard_error.betaor <- function(model, component = c("all", "conditional", "precision"), ...) {
-  component = match.arg(component)
+  component <- match.arg(component)
   standard_error.betareg(model$fit, component = component, ...)
 }
 
@@ -1753,7 +1774,9 @@ standard_error.blavaan <- function(model, ci = .95, ...) {
         as.vector(sqrt(diag(vc)))
       }
     },
-    error = function(e) { NULL }
+    error = function(e) {
+      NULL
+    }
   )
 
   if (is.null(se)) {
@@ -1772,7 +1795,9 @@ standard_error.blavaan <- function(model, ci = .95, ...) {
           se <- stats::setNames(unname(sc$coefficients[, 4]), names(sc$coefficients[, 4]))
         }
       },
-      error = function(e) { NULL }
+      error = function(e) {
+        NULL
+      }
     )
   }
   se
