@@ -1,10 +1,9 @@
 if (require("testthat") &&
-    require("parameters") &&
-    require("psych") &&
-    require("lavaan") &&
-    require("BayesFM") &&
-    require("FactoMineR")) {
-
+  require("parameters") &&
+  require("psych") &&
+  require("lavaan") &&
+  require("BayesFM") &&
+  require("FactoMineR")) {
   test_that("principal_components", {
     set.seed(333)
 
@@ -35,7 +34,7 @@ if (require("testthat") &&
 
     testthat::expect_equal(nchar(model1), 109)
 
-    m1 <- lavaan::cfa(model1, data = attitude)
+    m1 <- suppressWarnings(lavaan::cfa(model1, data = attitude))
     params <- parameters::model_parameters(m1)
     testthat::expect_equal(c(nrow(params), ncol(params)), c(10, 9))
 
@@ -68,4 +67,4 @@ if (require("testthat") &&
   test_that("BayesFM", {
     testthat::expect_equal(nrow(params), 11)
   })
-}
\ No newline at end of file
+}
